<template>
    <div class="humidity-sensor">
        <div class="header">
            <div>
                上限<span style="font-size: 16px; color: #fa3e2e">80%</span>
            </div>
            <div>
                下限<span style="font-size: 16px; color: #4277ff">40%</span>
            </div>
        </div>
        <div class="content">
            <div
                class="box"
                style="--w: 200px; --n: 40; --t: 8px; --d: 3deg; --c: #15C646"
            >
                <div
                    ref="chartRef"
                    style="width: 200px; min-height: 200px"
                ></div>
            </div>
            <div class="flag">
                <span>0%</span>
                <span>100%</span>
            </div>
        </div>
    </div>
</template>
<script lang="ts" name="HumiditySensor" setup>
import * as echarts from 'echarts';
const chartRef = ref<Record<string, any>>({});
let myChart: any = null;

const props = defineProps({
    propertyData: {
        type: Object,
        default: () => {}
    }
});

watch(() => props.propertyData,
  (value) => {
    if(value && value.value &&value.value.property){
        console.log("=====watch===value==========",value.value.value)
        //handleOptions(35);
        if(myChart && value.value.property=="humidity"){
            myChart.setOption({
                series: [
                    { 
                        data: [
                            {
                                value: value.value.value,
                                name: 'RH',
                            },
                        ],
                    }
                ],
            });
        }
    }
  },
  { immediate: true }
)


const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        const options = {
            // grid: {
            //     top: '0%',
            //     left: '0%',
            //     right: '0%',
            //     bottom: '0%',
            //     containLabel: true,
            // },
            series: [
                {
                    type: 'gauge',
                    startAngle: 220,
                    endAngle: 320,
                    min: 0,
                    max: 100,
                    // splitNumber: 12,
                    // itemStyle: {
                    //   color: '#58D9F9',
                    //   shadowColor: 'rgba(0,138,255,0.45)',
                    //   shadowBlur: 10,
                    //   shadowOffsetX: 2,
                    //   shadowOffsetY: 2
                    // },
                    progress: {
                        show: true,
                        roundCap: true,
                        width: 9,
                        itemStyle: {
                            color: {
                                type: 'linear',
                                x: 0,
                                y: 0,
                                x2: 0,
                                y2: 1,
                                colorStops: [
                                    {
                                        offset: 0,
                                        color: 'blue', // 0% 处的颜色
                                    },
                                    {
                                        offset: 1,
                                        color: 'white', // 100% 处的颜色
                                    },
                                ],
                                global: false, // 缺省为 false
                            },
                        },
                    },
                    pointer: {
                        show: false,
                    },
                    axisLine: {
                        roundCap: true,
                        lineStyle: {
                            width: 9,
                        },
                    },
                    axisTick: {
                        show: false,
                    },
                    splitLine: {
                        show: false,
                    },
                    axisLabel: {
                        show: false,
                    },
                    title: {
                        show: true,
                        offsetCenter: [0, '30%'],
                        color: '#828282',
                    },
                    detail: {
                        offsetCenter: [0, '0%'],
                        formatter: '{value}%',
                    },
                    data: [
                        {
                            value: 0,
                            name: 'RH',
                        },
                    ],
                },
            ],
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

onMounted(() => {
    handleOptions();
});
</script>
<style scoped lang="less">
@import url('./dashedLine.less');
.humidity-sensor {
    width: 100%;
    height: 100%;
    background: #ffffff;
    box-shadow: 0px 2px 6px 0px #cccccc;
    border-radius: 4px 4px 4px 4px;
    padding: 19px;
    .header {
        display: flex;
        align-items: center;

        div {
            flex: 1;
            font-size: 14px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            text-align: center;
            color: #828282;
            line-height: 22px;
        }
    }
    .content {
        position: relative;
        width: 100%;
        padding: 24px;
        display: flex;
        align-items: center;
        justify-content: center;
        .flag {
            position: absolute;
            top: 175px;
            width: 180px;
            height: 50px;
            line-height: 40px;
            background: white;
            display: flex;
            justify-content: space-between;
        }
    }
}
</style>
